@@ -1,6 +1,6 @@
 egammaAltCensored.bootstrap.ci <-
-function (x, censored, censoring.side, est.fcn, ci.type, conf.level, 
-    n.bootstraps, obs.mean) 
+function (x, censored, censoring.side, est.fcn, ci.type, conf.level,
+    n.bootstraps, obs.mean)
 {
     N <- length(x)
     boot.vec <- numeric(n.bootstraps)
@@ -22,22 +22,22 @@ function (x, censored, censoring.side, est.fcn, ci.type, conf.level,
             no.cen.obs.count <- no.cen.obs.count + 1
         }
         else {
-            boot.vec[i] <- do.call(est.fcn, list(x = new.x, censored = new.censored, 
+            boot.vec[i] <- do.call(est.fcn, list(x = new.x, censored = new.censored,
                 censoring.side = censoring.side, ci = FALSE))$parameters["mean"]
         }
     }
     alpha <- 1 - conf.level
-    if (ci.type == "two.sided") 
+    if (ci.type == "two-sided")
         alpha <- alpha/2
-    ci.limits.pct <- switch(ci.type, `two-sided` = quantile(boot.vec, 
-        probs = c(alpha, 1 - alpha)), lower = c(quantile(boot.vec, 
-        probs = alpha), Inf), upper = c(0, quantile(boot.vec, 
+    ci.limits.pct <- switch(ci.type, `two-sided` = quantile(boot.vec,
+        probs = c(alpha, 1 - alpha)), lower = c(quantile(boot.vec,
+        probs = alpha), Inf), upper = c(0, quantile(boot.vec,
         probs = conf.level)))
     compute.bca <- length(unique(x.no.cen)) >= 3
     if (compute.bca) {
         za <- qnorm(alpha)
         z0 <- qnorm(sum(boot.vec <= obs.mean)/n.bootstraps)
-        jack.vec <- egammaAltCensored.jackknife(x = x, censored = censored, 
+        jack.vec <- egammaAltCensored.jackknife(x = x, censored = censored,
             censoring.side = censoring.side, est.fcn = est.fcn)
         num <- sum(as.vector(scale(jack.vec, scale = FALSE))^3)
         denom <- 6 * (((length(jack.vec) - 1) * var(jack.vec))^(3/2))
@@ -54,13 +54,13 @@ function (x, censored, censoring.side, est.fcn, ci.type, conf.level,
             c(0, quantile(boot.vec, probs = alpha2))
         })
     }
-    else ci.limits.bca <- switch(ci.type, `two-sided` = c(NA, 
+    else ci.limits.bca <- switch(ci.type, `two-sided` = c(NA,
         NA), lower = c(NA, Inf), upper = c(-Inf, NA))
     ci.limits <- c(ci.limits.pct, ci.limits.bca)
     names(ci.limits) <- c("Pct.LCL", "Pct.UCL", "BCa.LCL", "BCa.UCL")
-    ret.obj <- list(name = "Confidence", parameter = "mean", 
-        limits = ci.limits, type = ci.type, method = "Bootstrap", 
-        conf.level = conf.level, n.bootstraps = n.bootstraps, 
+    ret.obj <- list(name = "Confidence", parameter = "mean",
+        limits = ci.limits, type = ci.type, method = "Bootstrap",
+        conf.level = conf.level, n.bootstraps = n.bootstraps,
         too.few.obs.count = too.few.obs.count, no.cen.obs.count = no.cen.obs.count)
     oldClass(ret.obj) <- "intervalEstimateCensored"
     ret.obj
